@@ -227,6 +227,7 @@ class AwlQuery
         $this->bound_parameters = $args[0];
       else
         $this->bound_parameters = $args;
+//      print_r( $this->bound_parameters );
     }
 
     return $this;
@@ -238,15 +239,15 @@ class AwlQuery
   * @param  resource $new_connection The database connection to use.
   */
   function SetConnection( $new_connection, $options = null ) {
-    if ( is_string($new_connection) ) {
+    if ( is_string($new_connection) || is_array($new_connection) ) {
       $dbuser = null;
       $dbpass = null;
-      if ( is_array($v) ) {
-        $dsn = $v['dsn'];
-        if ( isset($v['dbuser']) ) $dbuser = $v['dbuser'];
-        if ( isset($v['dbpass']) ) $dbpass = $v['dbpass'];
+      if ( is_array($new_connection) ) {
+        $dsn = $new_connection['dsn'];
+        if ( isset($new_connection['dbuser']) ) $dbuser = $new_connection['dbuser'];
+        if ( isset($new_connection['dbpass']) ) $dbpass = $new_connection['dbpass'];
       }
-      elseif ( preg_match( '/^(\S+:)?(.*)( user=(\S+))?( password=(\S+))?$/', $v, $matches ) ) {
+      elseif ( preg_match( '/^(\S+:)?(.*)( user=(\S+))?( password=(\S+))?$/', $new_connection, $matches ) ) {
         $dsn = $matches[2];
         if ( isset($matches[1]) && $matches[1] != '' ) {
           $dsn = $matches[1] . $dsn;
@@ -372,34 +373,31 @@ class AwlQuery
     }
 
     if ( isset($c->expand_pdo_parameters) && $c->expand_pdo_parameters ) {
+      $this->bound_querystring = $this->querystring;
       if ( isset($this->bound_parameters) ) {
         $this->bound_querystring = $this->connection->ReplaceParameters($this->querystring,$this->bound_parameters);
 //        printf( "\n=============================================================== OQ\n%s\n", $this->querystring);
 //        printf( "\n=============================================================== QQ\n%s\n", $this->bound_querystring);
 //        print_r( $this->bound_parameters );
       }
-      else {
-        $this->bound_querystring = $this->querystring;
-      }
-    }
-
-    $t1 = microtime(true); // get start time
-    if ( isset($this->bound_querystring) ) {
+      $t1 = microtime(true); // get start time
       $this->sth = $this->connection->query($this->bound_querystring);
-      $this->bound_querystring = null;
-      if ( ! $this->sth ) {
-        $this->error_info = $this->connection->errorInfo();
-        return false;
-      }
     }
     else {
-      if ( ! $this->sth->execute( $this->bound_parameters ) ) {
-        $this->error_info = $this->sth->errorInfo();
-        return false;
-      }
+      $t1 = microtime(true); // get start time
+      $this->sth = $this->connection->prepare($this->querystring);
+      if ( $this->sth ) $this->sth->execute($this->bound_parameters);
+//      printf( "\n=============================================================== OQ\n%s\n", $this->querystring);
+//      print_r( $this->bound_parameters );
     }
+    $this->bound_querystring = null;
 
+    if ( ! $this->sth ) {
+      $this->error_info = $this->connection->errorInfo();
+      return false;
+    }
     $this->rows = $this->sth->rowCount();
+
     $i_took = microtime(true) - $t1;
     $c->total_query_time += $i_took;
     $this->execution_time = sprintf( "%2.06lf", $i_took);
@@ -433,6 +431,20 @@ class AwlQuery
   }
 
 
+  /**
+  * Returns the current state of a transaction, indicating if we have begun a transaction, whether the transaction
+  * has failed, or if we are not in a transaction.
+  */
+  function TransactionState() {
+    global $_awl_dbconn;
+    if ( !isset($this->connection) ) {
+      if ( !isset($_awl_dbconn) ) _awl_connect_configured_database();
+      $this->connection = $_awl_dbconn;
+    }
+    return $this->connection->TransactionState();
+  }
+
+
   /**
   * Wrap the parent DB class Begin() so we can $qry->Begin() sometime before we $qry->Exec()
   */
