@@ -6,7 +6,7 @@
 * @package   awl
 * @author Andrew McMillan <andrew@mcmillan.net.nz>
 * @copyright Catalyst IT Ltd, Morphoss Ltd <http://www.morphoss.com/>
-* @license   http://gnu.org/copyleft/gpl.html GNU GPL v2
+* @license   http://gnu.org/copyleft/gpl.html GNU GPL v2 or later
 */
 require_once("AWLUtilities.php");
 
@@ -149,7 +149,7 @@ class User extends DBRecord {
   function GetRoles () {
     $this->roles = array();
     $qry = new PgQuery( 'SELECT role_name FROM role_member JOIN roles USING (role_no) WHERE user_no = ? ', $this->user_no );
-    if ( $qry->Exec("User") && $qry->rows > 0 ) {
+    if ( $qry->Exec("User") && $qry->rows() > 0 ) {
       while( $role = $qry->Fetch() ) {
         $this->roles[$role->role_name] = 't';
       }
@@ -226,12 +226,12 @@ class User extends DBRecord {
               array( "size" => 50, "title" => translate("The user's e-mail address.")), $this->prefix );
 
     if ( $this->AllowedTo('ChangeActive') ) {
-      $html .= $ef->DataEntryLine( translate("Active"), ($this->Get('active') == 't'? 'Yes' : 'No'), "checkbox", "active",
+      $html .= $ef->DataEntryLine( translate("Active"), ($this->Get('active') == 't'? translate('Yes') : translate('No')), "checkbox", "active",
                 array( "_label" => translate("User is active"),
                       "title" => translate("Is this user active?")), $this->prefix );
     }
     else {
-      $html .= $ef->DataEntryLine( translate("Active"), ($this->Get('active') == 't'? 'Yes' : 'No') );
+      $html .= $ef->DataEntryLine( translate("Active"), ($this->Get('active') == 't'? translate('Yes') : translate('No')) );
     }
 
     $html .= $ef->DataEntryLine( translate("Date Style"), ($this->Get('date_format_type') == 'E' ? 'European' : ($this->Get('date_format_type') == 'U' ? 'US of A' : 'ISO 8861')),
@@ -285,7 +285,7 @@ class User extends DBRecord {
 
       // Select the records
       $q = new PgQuery($sql);
-      if ( $q && $q->Exec("User") && $q->rows ) {
+      if ( $q && $q->Exec("User") && $q->rows() ) {
         $i=0;
         while( $row = $q->Fetch() ) {
           @dbg_error_log("User", ":RenderRoles: Is a member of '%s': %s", $row->role_name, $this->roles[$row->role_name] );
@@ -319,7 +319,7 @@ class User extends DBRecord {
     $valid = true;
 
     if ( $this->Get('fullname') == "" ) {
-      $c->messages[] = "ERROR: The full name may not be blank.";
+      $c->messages[] = i18n('ERROR: The full name may not be blank.');
       $valid = false;
     }
 
@@ -330,7 +330,7 @@ class User extends DBRecord {
         $this->Set('password',$_POST['new_password']);
       }
       else {
-        $c->messages[] = "ERROR: The new password must match the confirmed password.";
+        $c->messages[] = i18n('ERROR: The new password must match the confirmed password.');
         $valid = false;
       }
     }
@@ -349,7 +349,7 @@ class User extends DBRecord {
   function Write() {
     global $c, $session;
     if ( parent::Write() ) {
-      $c->messages[] = translate("User record written.");
+      $c->messages[] = i18n('User record written.');
       if ( $this->WriteType == 'insert' ) {
         $qry = new PgQuery( "SELECT currval('usr_user_no_seq');" );
         $qry->Exec("User::Write");
@@ -397,11 +397,11 @@ class User extends DBRecord {
       $qry = new PgQuery($sql);
       if ( !$qry->Exec("Sys::Write") ) {
         if ( $session->AllowedTo("Admin") ) {
-          $client_messages[] = sprintf( translate("ERROR: %s"), $qry->errorstring);
+          $c->messages[] = sprintf( translate("ERROR: %s"), $qry->errorstring);
         }
         else {
-          $client_messages[] = translate("ERROR: There was a database error writing the roles information!");
-          $client_messages[] = translate("Please note the time and advise the administrator of your system.");
+          $c->messages[] = i18n('ERROR: There was a database error writing the roles information!');
+          $c->messages[] = i18n('Please note the time and advise the administrator of your system.');
         }
         return false;
       }
@@ -409,4 +409,3 @@ class User extends DBRecord {
     return true;
   }
 }
-?>
\ No newline at end of file
