@@ -277,10 +277,10 @@ class iCalProp {
       $this->rendered = $property . $escaped;
     }
     else if ( (strlen($property) + strlen($escaped)) > 72 && (strlen($property) < 72) && (strlen($escaped) < 72) ) {
-      $this->rendered = $property . " \r\n " . $escaped;
+      $this->rendered = $property . "\r\n " . $escaped;
     }
     else {
-      $this->rendered = wordwrap( $property . $escaped, 72, " \r\n ", true );
+      $this->rendered = preg_replace( '/(.{72})/u', '$1'."\r\n ", $property . $escaped );
     }
     return $this->rendered;
   }
@@ -484,7 +484,7 @@ class iCalComponent {
     $strs = preg_split( "/\r?\n/", $content );
     $wrapped = "";
     foreach ($strs as $str) {
-      $wrapped .= wordwrap($str, 73, " \r\n ") . "\r\n";
+      $wrapped .= preg_replace( '/(.{72})/u', '$1'."\r\n ", $str ) ."\r\n";
     }
     return $wrapped;
   }
@@ -1169,9 +1169,9 @@ class iCalendar {  // DEPRECATED
       }
       else {
         // Parse the property
-        @list( $property, $value ) = preg_split('/:/', $line, 2 );
+        @list( $property, $value ) = explode(':', $line, 2 );
         if ( strpos( $property, ';' ) > 0 ) {
-          $parameterlist = preg_split('/;/', $property );
+          $parameterlist = explode(';', $property );
           $property = array_shift($parameterlist);
           foreach( $parameterlist AS $pk => $pv ) {
             if ( $pv == "VALUE=DATE" ) {
@@ -1501,7 +1501,7 @@ class iCalendar {  // DEPRECATED
         $value = preg_replace( '/\r?\n/', '\\n', $value);
         $value = preg_replace( "/([,;:\"])/", '\\\\$1', $value);
     }
-    $result = wordwrap("$name:$value", 73, " \r\n ", true ) . "\r\n";
+    $result = preg_replace( '/(.{72})/u', '$1'."\r\n ", $name.':'.$value ) ."\r\n";
     return $result;
   }
 
